<?php

namespace Drupal\block_style_plugins\Plugin;

use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Extension\ThemeHandlerInterface;
use Drupal\Core\Plugin\Discovery\YamlDiscoveryDecorator;

/**
 * Provides the Block style plugin manager.
 */
class BlockStyleManager extends DefaultPluginManager {

  /**
   * A set of defaults to be referenced by $this->processDefinition().
   *
   * @var array
   */
  protected $defaults = [
    'class' => 'Drupal\block_style_plugins\Plugin\BlockStyle',
  ];

  /**
   * The theme handler.
   *
   * @var \Drupal\Core\Extension\ThemeHandlerInterface
   */
  protected $themeHandler;

  /**
   * Constructor for BlockStyleManager objects.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   * @param \Drupal\Core\Extension\ThemeHandlerInterface $theme_handler
   *   The theme handle to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler, ThemeHandlerInterface $theme_handler) {
    parent::__construct('Plugin/BlockStyle', $namespaces, $module_handler, 'Drupal\block_style_plugins\Plugin\BlockStyleInterface', 'Drupal\block_style_plugins\Annotation\BlockStyle');

    // Add in the Theme directory Discovery via Yaml file.
    $discovery = $this->getDiscovery();
    $this->discovery = new YamlDiscoveryDecorator($discovery, 'blockstyle', $module_handler->getModuleDirectories() + $theme_handler->getThemeDirectories());
    $this->themeHandler = $theme_handler;

    $this->alterInfo('block_style_plugins_info');
    $this->setCacheBackend($cache_backend, 'block_style_plugins');
  }

  /**
   * {@inheritdoc}
   */
  protected function providerExists($provider) {
    return $this->moduleHandler->moduleExists($provider) || $this->themeHandler->themeExists($provider);
  }

}
